#ifndef ACTIONSMANAGER_H
#define ACTIONSMANAGER_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include "action.h"
#include <qobject.h>
#include <qdatetime.h>

namespace SubtitleComposer
{
	class ActionsManager : public QObject
	{
		Q_OBJECT

		public:

			ActionsManager();

			bool hasRedo();
			bool hasUndo();

			QString redoDescription();
			QString undoDescription();

			void execAndStore( Action* action );

		public slots:

			void redo();
			void undo();
			void clearHistory();

		signals:

			void actionStored();
			void actionRedone();
			void actionUndone();
			void historyCleared();

		private:

			ActionsManager( const ActionsManager& undoManager );
			ActionsManager& operator=( const ActionsManager& undoManager );

			QPtrList<Action> m_undoStack;
			QPtrList<Action> m_redoStack;

			int m_compressionThreshold;
			QTime m_time;
	};


	/// a class to manage various ActionManager objects
	class ActionsManagerProxy : public QObject
	{
		Q_OBJECT

		public:

			ActionsManagerProxy();

			bool hasRedo();
			bool hasUndo();

			QString redoDescription();
			QString undoDescription();

			/// once the ActionsManager has been registered it should be handled only through the proxy
			void registerActionsManager( ActionsManager& actionsManager );
			void unregisterActionsManager( ActionsManager& actionsManager );

		public slots:

			void redo();
			void undo();
			void clearHistory();

		signals:

			void actionStored();
			void actionRedone();
			void actionUndone();
			void historyCleared();
			void stateChanged();

		private:

			ActionsManagerProxy( const ActionsManager& undoManager );
			ActionsManagerProxy& operator=( const ActionsManager& undoManager );

		private slots:

			void onActionStored();

		private:

			QPtrList<ActionsManager> m_undoStack;
			QPtrList<ActionsManager> m_redoStack;
	};

}

#endif
