/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "subtitleiterator.h"
#include "subtitleline.h"

using namespace SubtitleComposer;

SubtitleIterator::SubtitleIterator( const Subtitle& subtitle, const RangeList& ranges, bool gotoEnd ):
	m_ranges( ranges ),
	m_linesIterator( subtitle.m_lines )
{
	m_ranges.trim( subtitle.linesCount() );
	m_rangesEnd = m_ranges.end();

	if ( m_ranges.isEmpty() )
		m_index = -3; // no operations allowed
	else
	{
		if ( gotoEnd )
			toEnd();
		else
			toStart();
	}
}

SubtitleIterator::SubtitleIterator( const SubtitleIterator& it ):
	m_ranges( it.m_ranges ),
	m_index( it.m_index ),
	m_rangesIterator( it.m_rangesIterator ),
	m_rangesEnd( it.m_rangesEnd ),
	m_linesIterator( it.m_linesIterator )
{
}

SubtitleIterator& SubtitleIterator::operator=( const SubtitleIterator& it )
{
	if ( &it != this )
	{
		m_ranges = it.m_ranges;
		m_index = it.m_index;
		m_rangesIterator = it.m_rangesIterator;
		m_rangesEnd = it.m_rangesEnd;
		m_linesIterator = it.m_linesIterator;
	}

	return *this;
}

SubtitleIterator::~SubtitleIterator()
{
}

void SubtitleIterator::toStart()
{
	if ( m_index == -3 )
		return;

	m_rangesIterator = m_ranges.begin();

	m_index = m_ranges.firstIndex();
	m_linesIterator.toFirst();
	if ( m_index )
		m_linesIterator += m_index;
}

void SubtitleIterator::toEnd()
{
	if ( m_index == -3 )
		return;

	m_rangesIterator = m_ranges.end();
	m_rangesIterator--;

	m_index = m_ranges.lastIndex();
	m_linesIterator.toFirst();
	if ( m_index )
		m_linesIterator += m_index;
}

SubtitleIterator& SubtitleIterator::operator++()
{
	if ( m_index == -3 || m_index == -1 )
		return *this;

	if ( m_index == -2 )
		toStart();
	else
	{
		m_index++;
		++m_linesIterator;

		int currentRangeEnd = (*m_rangesIterator).end();
		if ( m_index > currentRangeEnd )
		{
			m_rangesIterator++;
			if ( m_rangesIterator == m_rangesEnd )
				m_index = -1;
			else
			{
				m_index = (*m_rangesIterator).start();
				m_linesIterator += (m_index - (currentRangeEnd + 1));
			}
		}
	}

	return *this;
}


SubtitleIterator& SubtitleIterator::operator+=( int count )
{
	if ( count > 0 )
	{
		for ( int i = 0; i < count; ++i )
			operator ++();
	}
	else if ( count < 0 )
	{
		for ( int i = 0; i > count; --i )
			operator --();
	}

	return *this;
}

SubtitleIterator& SubtitleIterator::operator--()
{
	if (  m_index == -3 || m_index == -2 )
		return *this;

	if ( m_index == -1 )
		toEnd();
	else
	{
		m_index--;
		--m_linesIterator;

		int currentRangeStart = (*m_rangesIterator).start();
		if ( m_index < currentRangeStart )
		{
			m_rangesIterator--;
			m_index = (*m_rangesIterator).end();
			m_linesIterator -= (currentRangeStart - (m_index - 1));
		}
	}

	return *this;
}

SubtitleIterator& SubtitleIterator::operator-=( int count )
{
	if ( count > 0 )
	{
		for ( int i = 0; i < count; ++i )
			operator --();
	}
	else if ( count < 0 )
	{
		for ( int i = 0; i > count; --i )
			operator ++();
	}

	return *this;
}


bool SubtitleIterator::operator==( const SubtitleIterator& it )
{
	return m_index == it.m_index;
}
