#ifndef INPUTFORMAT_H
#define INPUTFORMAT_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include "format.h"
#include <subtitle.h>

#include <qstringlist.h>
#include <qfile.h>
#include <qfileinfo.h>
#include <qtextcodec.h>
#include <kdebug.h>

namespace SubtitleComposer
{
	class InputFormat : public Format
	{
		public:

			~InputFormat() {}

			bool readSubtitle( Subtitle& subtitle, const QString& path, QTextCodec* codec, bool ignoreExtension ) const
			{
				if ( ! ignoreExtension )
				{
					QString extension( QFileInfo( path ).extension( false ) );

					if ( ! knowsExtension( extension ) )
						return false;
				}

				QFile file( path );
				if ( ! file.open( IO_ReadOnly ) )
				{
					kdDebug() << "copy: couldn't open input file " << file.name() << endl;
					return false;
				}

				QString subtitleText;

				QTextDecoder* decoder = codec->makeDecoder();
				char* data = new char[262144];
				int read = file.readBlock( data, 262144 );
				while ( read != -1 && read != 0 )
				{
					subtitleText += decoder->toUnicode( data, read );
					read = file.readBlock( data, 262144 );
				}

				delete [] data;
				delete decoder;
				file.close();

				subtitleText.replace( "\r\n", "\n" );
				subtitleText.replace( "\r", "\n" );

				return parseSubtitles( subtitle, subtitleText );
			}

			virtual bool parseSubtitles( Subtitle& subtitle, const QString& subtitleText ) const = 0;

		protected:

			InputFormat( const QString& name, const QStringList& extensions ):
				Format( name, extensions ) {}
	};
}

#endif
