#ifndef MICRODVDINPUTFORMAT_H
#define MICRODVDINPUTFORMAT_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <inputformat.h>
#include <qregexp.h>

namespace SubtitleComposer
{
	class MicroDVDInputFormat : public InputFormat
	{
		friend class FormatsManager;

		public:
			~MicroDVDInputFormat() {}

			virtual bool parseSubtitles( Subtitle& subtitle, const QString& subtitleText ) const
			{
				if ( m_lineRegExp.search( subtitleText, 0 ) == -1 )
					return false; // couldn't find first line (content or FPS)

				int lineStart = 0;

				bool ok;
				double framesPerSecond = m_lineRegExp.cap( 4 ).toDouble( &ok );
				if ( ok && m_lineRegExp.cap( 1 ) == m_lineRegExp.cap( 2 ) && m_lineRegExp.cap( 1 ) == QString( "1" ) )
				{
					 // first line contains FPS
					lineStart += m_lineRegExp.matchedLength();
					if ( m_lineRegExp.search( subtitleText, lineStart ) == -1 )
						return false; // couldn't find first line with content
				}
				else // first line doesn't contain the FPS, use default value
					framesPerSecond = Subtitle::defaultFramesPerSecond();

				subtitle.setFramesPerSecond( framesPerSecond );

				do
				{
					lineStart += m_lineRegExp.matchedLength();

					Time showTime( (int)((m_lineRegExp.cap( 1 ).toInt() / framesPerSecond)*1000) );
					Time hideTime( (int)((m_lineRegExp.cap( 2 ).toInt() / framesPerSecond)*1000) );

					QString text( m_lineRegExp.cap( 4 ) );
					text.replace( "|", "\n" );
					text.replace( m_unsupportedFormatRegExp, "" );

					int style = 0;
					QString styleText( m_lineRegExp.cap( 3 ) );
					if ( styleText.contains( 'b' ) )
						style |= SubtitleLine::Bold;
					if ( styleText.contains( 'i' ) )
						style |= SubtitleLine::Italic;
					if ( styleText.contains( 'u' ) )
						style |= SubtitleLine::Underline;

					subtitle.insertLine( new SubtitleLine( text, showTime, hideTime, style ) );
				}
				while ( m_lineRegExp.search( subtitleText, lineStart ) != -1 );

				return subtitle.linesCount() > 0;
			}

		protected:

			MicroDVDInputFormat():
				InputFormat( "MicroDVD", QStringList::split( ":", "sub:txt" ) ),
				m_lineRegExp( "\\{(\\d+)\\}\\{(\\d+)\\}(\\{Y:[ubi]\\}|)([^\n]+)\n" ),
				m_unsupportedFormatRegExp( "\\{C:\\$[0-9A-Fa-f]{6,6}\\}" )
			{
			}

			mutable QRegExp m_lineRegExp;
			mutable QRegExp m_unsupportedFormatRegExp;
	};
}

#endif

