#ifndef MPLAYERINPUTFORMAT_H
#define MPLAYERINPUTFORMAT_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <inputformat.h>
#include <qregexp.h>

namespace SubtitleComposer
{
	class MPlayerInputFormat : public InputFormat
	{
		friend class FormatsManager;

		public:
			~MPlayerInputFormat() {}

			virtual bool parseSubtitles( Subtitle& subtitle, const QString& subtitleText ) const
			{
				double framesPerSecond = Subtitle::defaultFramesPerSecond();
				subtitle.setFramesPerSecond( framesPerSecond );

				int lineStart = 0;
				while ( m_lineRegExp.search( subtitleText, lineStart ) != -1 )
				{
					Time showTime( (int)((m_lineRegExp.cap( 1 ).toInt() / framesPerSecond)*1000) );
					Time hideTime( (int)((m_lineRegExp.cap( 2 ).toInt() / framesPerSecond)*1000) );

					subtitle.insertLine( new SubtitleLine( m_lineRegExp.cap( 3 ).replace( "|", "\n" ), showTime, hideTime, 0 ) );

					lineStart += m_lineRegExp.matchedLength();
				}

				return subtitle.linesCount() > 0;
			}

		protected:

			MPlayerInputFormat():
				InputFormat( "MPlayer", "mpl" ),
				m_lineRegExp( "(\\d+),(\\d+),0,([^\n]+)\n" )
			{
			}

			mutable QRegExp m_lineRegExp;
	};
}

#endif

