#ifndef MPLAYEROUTPUTFORMAT_H
#define MPLAYEROUTPUTFORMAT_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <outputformat.h>
#include <qstring.h>

namespace SubtitleComposer
{
	class MPlayerOutputFormat : public OutputFormat
	{
		friend class FormatsManager;

		public:
			~MPlayerOutputFormat() {}

			virtual QString dumpSubtitles( const Subtitle& subtitle ) const
			{
				QString ret;

				double framesPerSecond = subtitle.framesPerSecond();

				const int size = subtitle.linesCount();
				for ( int idx = 0; idx < size; ++idx )
				{
					const SubtitleLine* line = subtitle.line( idx );

					int showFrame = (int)((line->showTime().timeMillis()/1000.0)*framesPerSecond + 0.5);
					int hideFrame = (int)((line->hideTime().timeMillis()/1000.0)*framesPerSecond + 0.5);

					ret += m_lineBuilder
						.arg( showFrame )
						.arg( hideFrame )
						.arg( line->text().replace( "\n", "|" ) );
				}

				return ret;
			}

		protected:

			MPlayerOutputFormat():
				OutputFormat( "MPlayer", "mpl" ),
				m_lineBuilder( "%1,%2,0,%3\n" )
			{
			}

			const QString m_lineBuilder;
	};
}

#endif
