#ifndef OUTPUTFORMAT_H
#define OUTPUTFORMAT_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include "format.h"

#include <qstringlist.h>
#include <qfile.h>
#include <qtextcodec.h>

namespace SubtitleComposer
{
	class OutputFormat : public Format
	{
		public:

			~OutputFormat() {}

			bool writeSubtitle( const Subtitle& subtitle, const QString& path, QTextCodec* codec=QTextCodec::codecForLocale(), bool overwrite=true ) const
			{
				if ( ! overwrite )
				{
					if ( QFile::exists( path ) )
						return false;
				}

				QFile file( path );
				if ( ! file.open( IO_WriteOnly|IO_Truncate ) )
				{
					kdDebug() << "copy: couldn't open output file " << file.name() << endl;
					return false;
				}

				QString subtitleText = dumpSubtitles( subtitle );

				QTextStream stream( &file );
				stream.setCodec( codec );
				stream << subtitleText;

				file.close();

				return true;
			}

			virtual QString dumpSubtitles( const Subtitle& subtitle ) const = 0;

		protected:

			OutputFormat( const QString& name, const QStringList& extensions ):
				Format( name, extensions ) {}
	};

}

#endif
