#ifndef POLSKAINPUTFORMAT_H
#define POLSKAINPUTFORMAT_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <inputformat.h>
#include <qregexp.h>

namespace SubtitleComposer
{
	class PolskaInputFormat : public InputFormat
	{
		friend class FormatsManager;

		public:
			~PolskaInputFormat() {}

			virtual bool parseSubtitles( Subtitle& subtitle, const QString& subtitleText ) const
			{
				subtitle.setFramesPerSecond( Subtitle::defaultFramesPerSecond() );

				for ( int idx = 0; m_regExp.search( subtitleText, idx ) != -1; idx += m_regExp.matchedLength() )
				{
					Time showTime(
						m_regExp.cap( 1 ).toInt(),
						m_regExp.cap( 2 ).toInt(),
						m_regExp.cap( 3 ).toInt(),
						0
					);

					QString lineText( m_regExp.cap( 4 ) );
					lineText.replace( "|", "\n" );

					subtitle.insertLine( new SubtitleLine( lineText.stripWhiteSpace(), showTime, showTime, 0 ) );
				}

				if ( ! subtitle.linesCount() )
					return false;

				const int size = subtitle.linesCount();
				SubtitleLine* line = subtitle.line( 0 );
				SubtitleLine* nextLine = subtitle.line( 1 );
				for ( int idx = 1; idx < size; ++idx, line = nextLine, nextLine = subtitle.line( idx ) )
					line->setHideTime( nextLine->showTime() - 1 );
				line->setHideTime( line->showTime() + 2000 );

				return true;
			}

		protected:

			PolskaInputFormat():
				InputFormat( "Polska", "txt" ),
				m_regExp( "([0-2][0-9]):([0-5][0-9]):([0-5][0-9]):([^\n]*)\n?" )
			{
			}

			mutable QRegExp m_regExp;
	};
}

#endif

