#ifndef SUBRIPINPUTFORMAT_H
#define SUBRIPINPUTFORMAT_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <inputformat.h>
#include <qregexp.h>

namespace SubtitleComposer
{
	class SubRipInputFormat : public InputFormat
	{
		friend class FormatsManager;

		public:
			~SubRipInputFormat() {}

			virtual bool parseSubtitles( Subtitle& subtitle, const QString& subtitleText ) const
			{
				if ( m_regExp.search( subtitleText, 0 ) == -1 )
					return false; // couldn't find first line

				subtitle.setFramesPerSecond( Subtitle::defaultFramesPerSecond() );

				int lineStart = 0;
				do
				{
					Time showTime(
						m_regExp.cap( 1 ).toInt(),
						m_regExp.cap( 2 ).toInt(),
						m_regExp.cap( 3 ).toInt(),
						m_regExp.cap( 4 ).toInt()
					);

					Time hideTime(
						m_regExp.cap( 5 ).toInt(),
						m_regExp.cap( 6 ).toInt(),
						m_regExp.cap( 7 ).toInt(),
						m_regExp.cap( 8 ).toInt()
					);

					lineStart += m_regExp.matchedLength();

					QString lineText(
						subtitleText.mid(
							lineStart,
							((unsigned)m_regExp.search( subtitleText, lineStart ) - lineStart)
						)
					);

					lineStart += lineText.length();

					int styles = 0;
					if ( lineText.contains( m_boldRegExp ) )
						styles |= SubtitleLine::Bold;
					if ( lineText.contains( m_italicRegExp ) )
						styles |= SubtitleLine::Italic;
					if ( lineText.contains( m_underlineRegExp ) )
						styles |= SubtitleLine::Underline;

					lineText.replace( m_boldRegExp, "" );
					lineText.replace( m_italicRegExp, "" );
					lineText.replace( m_underlineRegExp, "" );

					subtitle.insertLine( new SubtitleLine( lineText.stripWhiteSpace(), showTime, hideTime, styles ) );
				}
				while ( m_regExp.matchedLength() != -1 );

				return subtitle.linesCount() > 0;
			}

		protected:

			SubRipInputFormat():
				InputFormat( "SubRip", "srt" ),
				m_regExp( "[\\d]+\n([0-2][0-9]):([0-5][0-9]):([0-5][0-9]),([0-9][0-9][0-9]) --> ([0-2][0-9]):([0-5][0-9]):([0-5][0-9]),([0-9][0-9][0-9])\n" ),
				m_boldRegExp( "</?[bB]>" ),
				m_italicRegExp( "</?[iI]>" ),
				m_underlineRegExp( "</?[uU]>" )
			{
			}

			mutable QRegExp m_regExp;
			mutable QRegExp m_boldRegExp;
			mutable QRegExp m_italicRegExp;
			mutable QRegExp m_underlineRegExp;
	};
}

#endif

