#ifndef SUBSTATIONALPHAOUTPUTFORMAT_H
#define SUBSTATIONALPHAOUTPUTFORMAT_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <outputformat.h>
#include <qstring.h>

namespace SubtitleComposer
{
	class SubStationAlphaOutputFormat : public OutputFormat
	{
		friend class FormatsManager;

		public:
			~SubStationAlphaOutputFormat() {}

			virtual QString dumpSubtitles( const Subtitle& subtitle ) const
			{
				QString ret( m_header );

				const int size = subtitle.linesCount();
				for ( int idx = 0; idx < size; ++idx )
				{
					const SubtitleLine* line = subtitle.line( idx );

					Time showTime = line->showTime();
					QString showTimeArg = m_builder.sprintf(
						"%01d:%02d:%02d.%02d",
						showTime.hours(),
						showTime.minutes(),
						showTime.seconds(),
						(showTime.mseconds() + 5)/10
					);

					Time hideTime = line->hideTime();
					QString hideTimeArg = m_builder.sprintf(
						"%01d:%02d:%02d.%02d",
						hideTime.hours(),
						hideTime.minutes(),
						hideTime.seconds(),
						(hideTime.mseconds() + 5)/10
					);

					int styleFlags = line->styleFlags();
					ret += m_textBuilder
						.arg( showTimeArg )
						.arg( hideTimeArg )
						.arg( styleFlags & SubtitleLine::Italic ? m_italicStart : QString::null )
						.arg( styleFlags & SubtitleLine::Bold ? m_boldStart : QString::null )
						.arg( line->text().replace( "\n", "\\n" ) )
						.arg( styleFlags & SubtitleLine::Italic ? m_italicEnd : QString::null )
						.arg( styleFlags & SubtitleLine::Bold ? m_boldEnd : QString::null );
				}

				return ret;
			}

		protected:

			SubStationAlphaOutputFormat():
				OutputFormat( "SubStation Alpha", "ssa" ),
				m_header( s_header ),
				m_textBuilder( "Dialogue: Marked=0,%1,%2,Default,,0000,0000,0000,,%3%4%5%6%7\n" ),
				m_boldStart( "{\\b1}" ),
				m_boldEnd( "{\\b0}" ),
				m_italicStart( "{\\i1}" ),
				m_italicEnd( "{\\i0}" ),
				m_builder()
			{
			}

			SubStationAlphaOutputFormat( const QString& name, const QStringList& extensions, const QString& header, const QString& textBuilder ):
				OutputFormat( name, extensions ),
				m_header( header ),
				m_textBuilder( textBuilder ),
				m_boldStart( "{\\b1}" ),
				m_boldEnd( "{\\b0}" ),
				m_italicStart( "{\\i1}" ),
				m_italicEnd( "{\\i0}" ),
				m_builder()
			{
			}

			static const char* s_header;
			const QString m_header;
			const QString m_textBuilder;
			const QString m_boldStart;
			const QString m_boldEnd;
			const QString m_italicStart;
			const QString m_italicEnd;
			mutable QString m_builder;
	};

	const char* SubStationAlphaOutputFormat::s_header =
		"[Script Info]\n"
		"Title: Untitled\n"
		"ScriptType: V4.00\n"
		"Collisions: Normal\n"
		"Timer: 100\n"
		"WrapStyle: 0\n\n"
		"[V4 Styles]\n"
		"Format: Name, Fontname, Fontsize, PrimaryColour, SecondaryColour, TertiaryColour, BackColour, "
		"Bold, Italic, BorderStyle, Outline, Shadow, Alignment, MarginL, MarginR, MarginV, AlphaLevel, Encoding\n\n"
		"[Events]\n"
		"Format: Marked, Start, End, Style, Name, MarginL, MarginR, MarginV, Effect, Text\n";

	class AdvancedSubStationAlphaOutputFormat : public SubStationAlphaOutputFormat
	{
		friend class FormatsManager;

		protected:

			AdvancedSubStationAlphaOutputFormat():
				SubStationAlphaOutputFormat( "Advanced SubStation Alpha", "ass", s_header, "Dialogue: 0,%1,%2,Default,,0000,0000,0000,,%3%4%5%6%7\n" )
			{
			}

			static const char* s_header;
	};

	const char* AdvancedSubStationAlphaOutputFormat::s_header =
		"[Script Info]\n"
		"Title: Untitled\n"
		"ScriptType: V4.00+\n"
		"Collisions: Normal\n"
		"Timer: 100\n"
		"WrapStyle: 0\n\n"
		"[V4+ Styles]\n"
		"Format: Name, Fontname, Fontsize, PrimaryColour, SecondaryColour, OutlineColour, BackColour, Bold, Italic, Underline, StrikeOut, ScaleX, ScaleY, Spacing, Angle, BorderStyle, Outline, Shadow, Alignment, MarginL, MarginR, MarginV, Encoding\n\n"
		"[Events]\n"
		"Format: Layer, Start, End, Style, Actor, MarginL, MarginR, MarginV, Effect, Text\n";

}

#endif
