#ifndef ACTIONS_H
#define ACTIONS_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <kaction.h>

#include <qptrlist.h>
#include <kurl.h>

namespace SubtitleComposer
{
	class Subtitle;
	class SubtitleActionWrapper;

	class SubtitleActionWrappersManager
	{
		friend class SubtitleActionWrapper;

		public:

			static SubtitleActionWrappersManager& instance();

			SubtitleActionWrappersManager( KActionCollection* actionCollection=0 );

			KActionCollection* actionCollection();
			void setActionCollection( KActionCollection* actionCollection );

			void setSubtitle( Subtitle* subtitle );
			void setViewState( int itemsCount, bool hasSelection );

			void addAction( SubtitleActionWrapper* subtitleAction );
			void removeAction( SubtitleActionWrapper* subtitleAction );

		private:

			KActionCollection* m_actionCollection;
			QPtrList<SubtitleActionWrapper> m_subtitleActions;
	};


	class SubtitleActionWrapper : public QObject
	{
		Q_OBJECT

		public:

			typedef enum { Opened=0, HasLine, HasMultipleLines, HasSelectedLine } EnableMode;

			SubtitleActionWrapper( KAction* action, EnableMode enableMode=Opened );

			KAction* action();

			EnableMode enableMode();
			void setEnableMode( EnableMode enableMode );

			void setSubtitle( Subtitle* subtitle );
			void setViewState( int itemsCount, bool hasSelection );

			bool isEnabled();
			void setEnabled( bool enabled );

		private:

			void updateEnabled();

		private slots:

			void onActionEnabled( bool enabled );

		private:

			KAction* m_action;
			EnableMode m_enableMode;

			bool m_actionEnabled;
			bool m_subViewEnabled;

			bool m_updateActionEnabled;
	};




	class KActionExt : public KAction
	{
		Q_OBJECT

		public:

			KActionExt( KActionCollection* parent=0, const char* name=0 );

			virtual int plug( QWidget* widget, int index=-1 );
			virtual void unplug( QWidget* widget );
	};

	class KToggleActionExt : public KToggleAction
	{
		Q_OBJECT

		public:

			KToggleActionExt( KActionCollection* parent=0, const char* name=0 );

			void setText( const QString& text );
			void setText( const QString& offText, const QString& onText );

			virtual int plug( QWidget* widget, int index=-1 );
			virtual void unplug( QWidget* widget );

		signals:

			void signalSetTextLabel( const QString& textLabel );

		public slots:

			virtual void setChecked( bool checked );

		protected:

			QString m_offText;
			QString m_onText;
	};


	/// Taken from KDELibs and rewritten almost entirely because the
	/// KDE3 implementations is buggy and limited for our needs.
	class KRecentFilesActionExt : public KSelectAction
	{
		Q_OBJECT
		Q_PROPERTY( uint maxItems READ maxItems WRITE setMaxItems )

		public:

			KRecentFilesActionExt( QObject* parent=0, const char* name=0 );
			virtual ~KRecentFilesActionExt();

			virtual int plug( QWidget* widget, int index=-1 );

			bool hasItems() const;

			const KURL::List& urls() const;

			uint maxItems() const;

			bool ignoreURLQueryItems() const;

		public slots:

			void setURLs( const KURL::List& urls );

			void setMaxItems( uint maxItems );

			void setIgnoreURLQueryItems( bool value );

			void add( const KURL& url );
			void remove( const KURL& url );
			void clear();

			void loadEntries( KConfig* config, const QString& groupName=QString::null );
			void saveEntries( KConfig* config, const QString& groupName=QString::null );

		signals:

			void urlSelected( const KURL& url );

		protected slots:

			void onItemActivated( const QString& string );
			void onItemActivated( int id );
			void onPopupMenuAboutToShow();

			void slotClicked();
			virtual void slotActivated();

		protected:

			void setItems( QStringList& items );
			QStringList buildItems( const KURL::List& urls );
			void buildAndSetItems( const KURL::List& urls );

			virtual void virtual_hook( int id, void* data );

			uint m_maxItems;
			bool m_ignoreURLQueryItems;
			KPopupMenu* m_popup;

			KURL::List m_urls;
	};



}

#endif
