#ifndef ACTIONSDIALOGS_H
#define ACTIONSDIALOGS_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <sctime.h>
#include <subtitle.h>

#include <kdialogbase.h>
#include <klocale.h>

class QPushButton;
class QRadioButton;
class QButtonGroup;
class QGroupBox;
class KComboBox;
class TimeEdit;
class QLabel;
class QSpinBox;
class QCheckBox;
class QGridLayout;
class KIntNumInput;
class KURLRequester;
class KLineEdit;
class KPushButton;

namespace SubtitleComposer
{
	class ErrorsView;

	class ActionDialog : public KDialogBase
	{
		public:

			ActionDialog( const QString& title, QWidget* parent=0, const char* name=0 );

		protected:

			QButtonGroup* createButtonGroup( const QString& title=QString::null, bool addToLayout=true );
			QGroupBox* createGroupBox( const QString& title=QString::null, bool addToLayout=true );
			QGridLayout* createLayout( QGroupBox* groupBox );

		protected:

			QWidget* m_mainWidget;
			QGridLayout* m_mainLayout;
	};

	class SelectableTargetActionDialogBase : public ActionDialog
	{
		public:

			bool selectedLinesOnlyMode();
			void setSelectedLinesOnlyMode( bool value );

			bool allLines();
			bool selectedLines();

		protected:

			SelectableTargetActionDialogBase( const QString& title, QWidget* parent=0, const char* name=0 );

			QButtonGroup* createTargetButtonGroup( const QString& title=i18n( "Apply action to" ), bool addToLayout=true );

		protected:

			QButtonGroup* m_targetButtonGroup;
			QGridLayout* m_targetButtonGroupLayout;

			QRadioButton* m_selectedLinesRadioButton;
			QRadioButton* m_allLinesRadioButton;

		private:

			bool m_selectedLinesOnlyMode;
			bool m_selectedLinesOldValue;
	};

	class SelectableTargetActionDialog : public SelectableTargetActionDialogBase
	{
		Q_OBJECT

		public:

			SelectableTargetActionDialog( const QString& title, const QString& desc, QWidget* parent=0, const char* name=0 );

		public slots:

			int exec();
	};

	class SelectableSubtitleDialog : public ActionDialog
	{
		Q_OBJECT

		public:

			SelectableSubtitleDialog( const QString& defaultEncoding, const QString& title, QWidget* parent=0, const char*name=0 );

			QString subtitlePath();
			QString subtitleEncoding();

		protected:

			QButtonGroup* createSubtitleButtonGroup( const QString& title=i18n( "Subtitle" ), bool addToLayout=true );

		private slots:

			void selectSubtitle();

		protected:

			QButtonGroup* m_subtitleButtonGroup;
			QGridLayout* m_subtitleButtonGroupLayout;

			KLineEdit* m_subtitlePathLineEdit;
			KComboBox* m_subtitleEncodingComboBox;

			QString m_defaultEncoding;
	};


	class AdjustLinesDialog : public ActionDialog
	{
		public:

			AdjustLinesDialog( QWidget* parent=0, const char* name=0 );

			Time firstLineTime();
			void setFirstLineTime( const Time& time );

			Time lastLineTime();
			void setLastLineTime( const Time& time );

		private:

			TimeEdit* m_firstLineTimeEdit;
			TimeEdit* m_lastLineTimeEdit;
	};


	class DurationLimitsDialog : public SelectableTargetActionDialogBase
	{
		Q_OBJECT

		public:

			DurationLimitsDialog( const Time& minDuration, const Time& maxDuration, QWidget* parent=0, const char* name=0 );

			Time minDuration();
			Time maxDuration();

			bool enforceMaxDuration();
			bool enforceMinDuration();
			bool preventOverlap();

		private slots:

			void onMinDurationValueChanged( int value );
			void onMaxDurationValueChanged( int value );

		private:

			QGroupBox* m_maxGroupBox;
			TimeEdit* m_maxDurationTimeEdit;

			QGroupBox* m_minGroupBox;
			QCheckBox* m_preventOverlapCheckBox;
			TimeEdit* m_minDurationTimeEdit;
	};


	class AutoDurationsDialog : public SelectableTargetActionDialogBase
	{
		public:

			AutoDurationsDialog( unsigned charMillis, unsigned wordMillis, unsigned lineMillis, QWidget* parent=0, const char* name=0 );

			unsigned charMillis();
			unsigned wordMillis();
			unsigned lineMillis();

			bool preventOverlap();

		private:

			KIntNumInput* m_charMillisSpinBox;
			KIntNumInput* m_wordMillisSpinBox;
			KIntNumInput* m_lineMillisSpinBox;

			QCheckBox* m_preventOverlapCheckBox;
	};


	class ShiftLinesDialog : public SelectableTargetActionDialogBase
	{
		public:

			ShiftLinesDialog( QWidget* parent=0, const char* name=0 );

			void resetShiftTime();

			int shiftTimeMillis();

		private:

			KComboBox* m_directionComboBox;
			TimeEdit* m_shiftTimeEdit;
	};


	class SmartLinesAdjustDialog : public SelectableTargetActionDialogBase
	{
		public:

			SmartLinesAdjustDialog( unsigned minLengthForLineBreak, QWidget* parent=0, const char* name=0 );

			unsigned minLengthForLineBreak();

		private:

			KIntNumInput* m_minLengthForLineBreakSpinBox;
	};

	class ChangeLinesTextCaseDialog : public SelectableTargetActionDialogBase
	{
		Q_OBJECT

		public:

			ChangeLinesTextCaseDialog( QWidget* parent=0, const char* name=0 );

			Subtitle::CaseOp caseOperation();
			bool lowerFirst();

		private slots:

			void onCaseButtonGroupClicked( int id );

		private:

			QCheckBox* m_lowerFirstCheckBox;

			QRadioButton* m_lowerRadioButton;
			QRadioButton* m_upperRadioButton;
			QRadioButton* m_titleRadioButton;
			QRadioButton* m_sentenceRadioButton;
	};

	class FixLinesPunctuationDialog : public SelectableTargetActionDialogBase
	{
		public:

			FixLinesPunctuationDialog( QWidget* parent=0, const char* name=0 );

			bool spaces();
			bool quotes();
			bool englishI();
			bool ellipisis();

		private:

			QCheckBox* m_spacesCheckBox;
			QCheckBox* m_quotesCheckBox;
			QCheckBox* m_englishICheckBox;
			QCheckBox* m_ellipsisCheckBox;
	};



	class CheckErrorsDialog : public SelectableTargetActionDialogBase
	{
		public:

			CheckErrorsDialog( QWidget* parent=0, const char* name=0 );

			int errorsToClear();

			bool clearOtherErrors();
			bool clearMarks();

		private:

			QCheckBox* m_errorsCheckBox[SubtitleLine::ErrorSIZE];

			QCheckBox* m_clearOtherErrorsCheckBox;
			QCheckBox* m_clearMarksCheckBox;
	};

	class ClearErrorsDialog : public SelectableTargetActionDialogBase
	{
		public:

			ClearErrorsDialog( QWidget* parent=0, const char* name=0 );

			int errorsToClear();
			bool clearMarks();

		private:

			QCheckBox* m_errorsCheckBox[SubtitleLine::ErrorSIZE];

			QCheckBox* m_marksCheckBox;
	};


	class ChangeFrameRateDialog : public ActionDialog
	{
		public:

			ChangeFrameRateDialog( double fromFramesPerSecond, QWidget* parent=0, const char* name=0 );

			double fromFramesPerSecond();
			void setFromFramesPerSecond( double framesPerSecond );

			double toFramesPerSecond();
			void setNewFramesPerSecond( double framesPerSecond );

		protected:

			virtual void accept();

		private:

			KComboBox* m_fromFramesPerSecondComboBox;
			KComboBox* m_toFramesPerSecondComboBox;
	};


	class SynchronizeWithSubtitleDialog : public SelectableSubtitleDialog
	{
		Q_OBJECT

		public:

			SynchronizeWithSubtitleDialog( const QString& defaultEncoding, QWidget* parent=0, const char* name=0 );

			bool adjustToReferenceSubtitle();
			bool synchronizeToReferenceTimes();

		private:

			QRadioButton* m_adjustRadioButton;
			QRadioButton* m_synchronizeRadioButton;
	};


	class JoinSubtitlesDialog : public SelectableSubtitleDialog
	{
		Q_OBJECT

		public:

			JoinSubtitlesDialog( const QString& defaultEncoding, QWidget* parent=0, const char* name=0 );

			Time shiftTime();

			virtual void show();

		private slots:

			void setShiftTimeFromVideo();

		private:

			TimeEdit* m_shiftTimeEdit;
			KPushButton* m_shiftTimeFromVideoButton;
			QCheckBox* m_shiftSubtitleCheckBox;
	};


	class SplitSubtitleDialog : public ActionDialog
	{
		Q_OBJECT

		public:

			SplitSubtitleDialog( QWidget* parent=0, const char* name=0 );

			Time splitTime();
			bool shiftNewSubtitle();

			virtual void show();

		private slots:

			void setSplitTimeFromVideo();

		private:

			TimeEdit* m_splitTimeEdit;
			KPushButton* m_splitTimeFromVideoButton;
			QCheckBox* m_shiftNewSubtitleCheckBox;
	};


	class GotoLineDialog : public KDialogBase
	{
		public:

			GotoLineDialog( int line, int linesCount, QWidget* parent=0, const char* name=0 );

			int lineNumber();

		private:

			KIntNumInput* lineNumInput;
	};
}

#endif
