/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "subtitletextconfigwidget.h"
#include "subtitletextconfigdefs.h"

#include <qpalette.h>
#include <qpushbutton.h>
#include <qgroupbox.h>
#include <qlabel.h>
#include <qlayout.h>

#include <kcolorcombo.h>
#include <kfontcombo.h>
#include <knuminput.h>

#include <klocale.h>

using namespace SubtitleComposer;

SubtitleTextConfigWidget::SubtitleTextConfigWidget( const AppConfigGroup& configGroup, QWidget* parent ):
	AppConfigGroupWidget( configGroup, parent, "SubtitleTextConfigWidget" )
{
	QGroupBox* fontGroupBox = createGroupBox( i18n( "Font" ) );

	QLabel* fontLabel = new QLabel( fontGroupBox );
	fontLabel->setText( i18n( "Family" ) );

	m_fontComboBox = new KFontCombo( fontGroupBox );

	QLabel* sizeLabel = new QLabel( fontGroupBox );
	sizeLabel->setText( i18n( "Size" ) );

	m_sizeSpinBox = new KIntNumInput( fontGroupBox );
	m_sizeSpinBox->setMinValue( 4 );
	m_sizeSpinBox->setMaxValue( 100 );

	QLabel* colorLabel = new QLabel( fontGroupBox );
	colorLabel->setText( i18n( "Color" ) );

	m_colorComboBox = new KColorCombo( fontGroupBox );


	QGroupBox* previewGroupBox = createGroupBox( i18n( "Preview" ) );

	m_previewLabel = new QLabel( previewGroupBox );
	m_previewLabel->setText( i18n( "<p align=\"center\">The Quick Brown Fox Jumps Over The Lazy Dog</p>" ) );
	m_previewLabel->setBackgroundColor( Qt::black );


	QGridLayout* fontLayout = createGridLayout( fontGroupBox );
	fontLayout->addWidget( fontLabel, 0, 0 );
	fontLayout->addWidget( m_fontComboBox, 0, 1 );
	fontLayout->addWidget( sizeLabel, 1, 0 );
	fontLayout->addWidget( m_sizeSpinBox, 1, 1 );
	fontLayout->addWidget( colorLabel, 2, 0 );
	fontLayout->addWidget( m_colorComboBox, 2, 1 );

	QGridLayout* previewLayout = createGridLayout( previewGroupBox );
	previewLayout->addItem( new QSpacerItem( 0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding ), 0, 0 );
	previewLayout->addWidget( m_previewLabel, 1, 0 );
	previewLayout->addItem( new QSpacerItem( 0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding ), 2, 0 );

	connect( m_fontComboBox, SIGNAL(activated(const QString&)), this, SLOT(onFamilyChanged(const QString&)) );
	connect( m_fontComboBox, SIGNAL(textChanged(const QString&)), this, SLOT(onFamilyChanged(const QString&)) );
	connect( m_sizeSpinBox, SIGNAL(valueChanged(int)), this, SLOT(onSizeChanged(int)) );
	connect( m_colorComboBox, SIGNAL(activated(const QColor&)), this, SLOT(onColorChanged(const QColor&)) );

	connect( m_fontComboBox, SIGNAL(activated(int)), this, SIGNAL(settingsChanged()) );
	connect( m_sizeSpinBox, SIGNAL(valueChanged(int)), this, SIGNAL(settingsChanged()) );
	connect( m_colorComboBox, SIGNAL(activated(const QColor&)), this, SIGNAL(settingsChanged()) );

	setControlsFromConfig();
}

SubtitleTextConfigWidget::~SubtitleTextConfigWidget()
{
}

void SubtitleTextConfigWidget::setControlsFromConfig()
{
	QString family( m_configGroup.option( OPT_FAMILY ) );
	m_fontComboBox->setCurrentFont( family );
	onFamilyChanged( family );

	int size = m_configGroup.optionAsInt( OPT_SIZE );
	m_sizeSpinBox->setValue( size );
	onSizeChanged( size );

	QColor color( m_configGroup.optionAsColor( OPT_COLOR ) );
	m_colorComboBox->setColor( color );
	onColorChanged( color );
}

void SubtitleTextConfigWidget::setConfigFromControls()
{
	QFont font( m_previewLabel->font() );
	m_configGroup.setOption( OPT_FAMILY, font.family() );
	m_configGroup.setOption( OPT_SIZE, font.pointSize() );

	QColor color( m_previewLabel->palette().color( QPalette::Normal, QColorGroup::Foreground ) );
	m_configGroup.setOption( OPT_COLOR, color );
}

void SubtitleTextConfigWidget::onFamilyChanged( const QString& family )
{
	if ( m_fontComboBox->contains( family ) )
	{
		QFont font( m_previewLabel->font() );
		font.setFamily( family );
		m_previewLabel->setFont( font );
	}
}

void SubtitleTextConfigWidget::onSizeChanged( int size )
{
	QFont font( m_previewLabel->font() );
	font.setPointSize( size );
	m_previewLabel->setFont( font );
}

void SubtitleTextConfigWidget::onColorChanged( const QColor& color )
{
	QPalette palette( m_previewLabel->palette() );
	palette.setColor( QPalette::Normal, QColorGroup::Foreground, color );
	palette.setColor( QPalette::Inactive, QColorGroup::Foreground, color );
	m_previewLabel->setPalette( palette );
}
