#ifndef ERRORSVIEW_H
#define ERRORSVIEW_H

/***************************************************************************
*   Copyright (C) 2007-2008 by Sergio Pistone                             *
*   sergio_pistone@yahoo.com.ar                                           *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <klistview.h>
#include <kdialogbase.h>

#include <appconfiggroup.h>
#include <subtitle.h>

namespace SubtitleComposer
{
	class LinesView;
	class ErrorsViewItem;

	class ErrorsView : public KListView
	{
		Q_OBJECT

		friend class ErrorsViewItem;

		public:

			ErrorsView( const AppConfig& config, LinesView* linesView, QWidget* parent );
			~ErrorsView();

			ErrorsViewItem* item( unsigned index );
			SubtitleLine* itemLine( QListViewItem* item );
			SubtitleLine* currentLine();

			unsigned linesCount();
			unsigned errorsCount();
			unsigned marksCount();

		public slots:

			void loadSubtitle( Subtitle* subtitle );
			void closeSubtitle();

			void setCurrentItem( QListViewItem* currentItem, bool clearSelection );
			void setCurrentLine( SubtitleLine* line );

			void showCheckErrors();
			void showClearErrors();
			void showSettings();

			void recheckAll();
			void recheckSelected();

			void clearAllErrors();
			void clearSelectedErrors();

			void clearAllMarks();
			void clearSelectedMarks();

		signals:

			void currentLineChanged( SubtitleLine* line );

			void linesCountChanged( unsigned linesCount );
			void errorsCountChanged( unsigned errorsCount );
			void marksCountChanged( unsigned marksCount );

		protected:

			ErrorsViewItem* createItem( SubtitleLine* line, ErrorsViewItem* after, unsigned number=0 );

			virtual void contextMenuEvent( QContextMenuEvent* e );
			virtual void contentsMouseDoubleClickEvent( QMouseEvent* e );
			virtual void keyPressEvent( QKeyEvent* e );

			void updateLinesCount( bool increment );
			void updateErrorsCount( bool increment );
			void updateMarksCount( bool increment );
			void updateLineErrors( SubtitleLine* line );

		protected slots:

			void syncInsertedLines( unsigned firstIndex, unsigned lastIndex );
			void syncRemovedLines( unsigned firstIndex, unsigned lastIndex );

			void onCurrentChanged( QListViewItem* currentItem );

		protected:

			LinesView* m_linesView;
			const AppConfigGroup& m_errorsConfig;
			Subtitle* m_subtitle;

			unsigned m_linesCount;
			unsigned m_errorsCount;
			unsigned m_marksCount;
	};

	class LinesErrorsDialog : public KDialogBase
	{
		Q_OBJECT

		public:

			LinesErrorsDialog( const AppConfig& config, LinesView* linesView, QWidget* parent=0, const char* name=0 );

			ErrorsView* errorsView();

		private slots:

			void onStatsChanged();
			void onOptionChanged( const QString& option, const QString& value );

		private:

			ErrorsView* m_errorsView;
			QPushButton* m_clearFixedButton;
			QLabel* m_statsLabel;
	};

}

#endif
