#ifndef ERRORSVIEWITEM_H
#define ERRORSVIEWITEM_H

/***************************************************************************
*   Copyright (C) 2007-2008 by Sergio Pistone                             *
*   sergio_pistone@yahoo.com.ar                                           *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <qobject.h>
#include <klistview.h>
#include <appconfiggroup.h>

namespace SubtitleComposer
{
	class ErrorsView;
	class ErrorsViewItem;

	class NestedErrorsViewItem : public QObject, public KListViewItem
	{
		Q_OBJECT

		public:

			friend class ErrorsViewItem;

			NestedErrorsViewItem( SubtitleLine::ErrorID id, ErrorsViewItem* parent );
			virtual ~NestedErrorsViewItem();

			ErrorsViewItem* parent();

			int errorFlags();

		private:

			static SubtitleLine::ErrorFlag errorFlag( SubtitleLine::ErrorID id );

			void update();

			const QPixmap& markPixmap();
			const QPixmap& errorPixmap();

		private:

			SubtitleLine::ErrorID m_id;
	};

	class ErrorsViewItem : public QObject, public KListViewItem
	{
		Q_OBJECT

		friend class NestedErrorsViewItem;

		public:

			ErrorsViewItem( SubtitleLine* line, ErrorsView* parent, ErrorsViewItem* after );
			virtual ~ErrorsViewItem();

			ErrorsView* errorsView();

			SubtitleLine* line();

			void setNumber( unsigned number );

			ErrorsViewItem* nextSiblingCasted();

			static const QString& errorText( SubtitleLine::ErrorID errorID, bool full=false );
			static const QString& errorText( SubtitleLine::ErrorFlag errorFlag, bool full=false );

		private:

			void setupItem( SubtitleLine::ErrorID id, bool active );

		private slots:

			void onErrorFlagsChanged( int errorFlags );
			void onMarkChanged( bool marked );

			void onTextChanged( const QString& text );
			void onTimesChanged( const Time& time );

		private:

			SubtitleLine* m_line;

			NestedErrorsViewItem* m_items[SubtitleLine::ErrorSIZE+1];
	};
}

#endif
