#ifndef FILEDIALOGS_H
#define FILEDIALOGS_H

/***************************************************************************
*   Copyright (C) 2007-2008 by Sergio Pistone                             *
*   sergio_pistone@yahoo.com.ar                                           *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <formatsmanager.h>

#include <kdebug.h>
#include <klocale.h>
#include <kencodingfiledialog.h>
#include <kfilefiltercombo.h>
#include <kmessagebox.h>

#include <qfileinfo.h>

namespace SubtitleComposer
{
	class OpenSubtitleDialog : public KEncodingFileDialog
	{
		public:

			OpenSubtitleDialog( const QString& startDir=QString::null, const QString& encoding=QString::null, QWidget *parent=0, const char* name="", bool modal=true ):
				KEncodingFileDialog( startDir, encoding, buildInputFormatsFilter(), i18n( "Open Subtitle" ), KFileDialog::Opening, parent, name, modal )
			{
			}

			static QString buildInputFormatsFilter()
			{
				static QString filter;

				if ( filter.isEmpty() )
				{
					QString allSupported;
					QStringList formats = FormatsManager::inputFormatNames();
					for ( QStringList::Iterator it = formats.begin(); it != formats.end(); ++it )
					{
						const InputFormat* format = FormatsManager::inputFormat( *it );
						QString extensions;
						for ( QStringList::ConstIterator extIt = format->extensions().begin(); extIt != format->extensions().end(); ++extIt )
							extensions += "*." + *extIt + " *." + (*extIt).upper();
						allSupported += " " + extensions;
						filter += "\n" + extensions + "|" + i18n( format->name() );
					}

					filter = allSupported + "|" + i18n( "All Supported" ) + filter;
					filter = filter.stripWhiteSpace();
				}

				return filter;
			}

	};


	class SaveSubtitleDialog : public KEncodingFileDialog
	{
		public:

			SaveSubtitleDialog( const QString& startDir=QString::null, const QString& encoding=QString::null, const QString& format=QString::null, QWidget *parent=0, const char* name="", bool modal=true ):
				KEncodingFileDialog( startDir, encoding, QString::null, i18n( "Save File" ), KFileDialog::Saving, parent, name, modal )
			{
				filterWidget->setFilter( buildOutputFormatsFilter() );

				QStringList formatNames = FormatsManager::outputFormatNames();
				if ( formatNames.findIndex( format ) != -1 )
					filterWidget->setCurrentItem( format, false );
				else
				{
					filterWidget->setCurrentItem( formatNames.first(), false );
					slotFilterChanged();
				}

				filterWidget->setEditable( false );
			}

			QString selectedFormat()
			{
				return filterWidget->currentText();
			}

			static QString buildOutputFormatsFilter()
			{
				static QString filter;

				if ( filter.isEmpty() )
				{
					QStringList formats = FormatsManager::outputFormatNames();
					for ( QStringList::Iterator it = formats.begin(); it != formats.end(); ++it )
					{
						const OutputFormat* format = FormatsManager::outputFormat( *it );
						QString extensions;
						for ( QStringList::ConstIterator extIt = format->extensions().begin(); extIt != format->extensions().end(); ++extIt )
							extensions += "*." + *extIt + " *." + (*extIt).upper();
						filter += "\n" + extensions + "|" + i18n( format->name() );
					}

					filter = filter.stripWhiteSpace();
				}

				return filter;
			}
	};
}

#endif
