#ifndef LINESVIEW_H
#define LINESVIEW_H

/***************************************************************************
*   Copyright (C) 2007-2008 by Sergio Pistone                             *
*   sergio_pistone@yahoo.com.ar                                           *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <klistview.h>
#include <appconfig.h>
#include <sctime.h>
#include <ranges.h>

class KFind;
class KFindDialog;
class KReplace;
class KReplaceDialog;
class KSpell;

namespace SubtitleComposer
{
	class Subtitle;
	class SubtitleLine;
	class LinesViewItem;
	class ConfigDialog;
	class LinesErrorsDialog;

	class LinesView : public KListView
	{
		Q_OBJECT

		friend class LinesViewItem;

		enum { Number=0, ShowTime, HideTime, Text };

		public:

			LinesView( const AppConfig& config, ConfigDialog* configDialog, QWidget* parent );
			~LinesView();

			void saveConfig();
			void loadConfig();

			int itemIndex( QListViewItem* item );
			LinesViewItem* item( unsigned index );

			SubtitleLine* currentLine();

		public slots:

			void loadSubtitle( Subtitle* subtitle );
			void closeSubtitle();

			void insertLineBefore();
			void insertLineAfter();
			void removeLines();

			void joinLines();
			void splitLines();

			void selectAllLines();

			void setCurrentItem( QListViewItem* currentItem, bool clearSelection, bool force=false );
			void setCurrentLine( SubtitleLine* line );

			void setCurrentLineShowTime( const Time& showTime );
			void setCurrentLineHideTime( const Time& hideTime );

			void adjustFromCurrentLine( const Time& currentLineShowTime );
			void adjustUpToCurrentLine( const Time& currentLineShowTime );

			void shiftFromCurrentLine( const Time& currentLineShowTime );
			void shiftUpToCurrentLine( const Time& currentLineShowTime );

			void setPlayingLine( SubtitleLine* line );

			void find( bool backwards=false );
			void findNext();
			void findPrevious();
			void replace();

			void gotoLine();

			void checkSpelling();

			void checkErrors();
			void clearErrors();
			void showErrors();
			void showErrorsConfig();
			void findNextError();
			void findPreviousError();

			void toggleLinesMark();

			void toggleLinesBold();
			void toggleLinesItalic();
			void toggleLinesUnderline();

			void shiftLines();
			void adjustLines();
			void sortLines();

			void changeFrameRate();
			void durationLimits();
			void autoDurations();
			void maximizeDurations();
			void syncWithSubtitle();

			void shiftSelectedLinesForwards();
			void shiftSelectedLinesBackwards();

			void smartLinesAdjust();
			void unbreakLines();
			void simplifySpaces();
			void changeCase();
			void fixPunctuation();

		signals:

			void currentLineChanged( SubtitleLine* line );
			void currentLineTextHighlighted( int startIndex, int endIndex );
			void lineDoubleClicked( SubtitleLine* line );

		private:

			void setupActions();

			RangeList selectionRanges();

			LinesViewItem* nextItem( LinesViewItem* item, const QString& caption, bool backwards=false, bool* circled=0 );
			LinesViewItem* createItem( SubtitleLine* line, LinesViewItem* after, unsigned number=0 );

			virtual void contextMenuEvent( QContextMenuEvent* e );
			virtual void contentsMouseDoubleClickEvent( QMouseEvent* e );

		private slots:

			void iterateFind();
			void iterateReplace();

			void updateActionsState();
			void syncInsertedLines( unsigned firstIndex, unsigned lastIndex );
			void syncRemovedLines( unsigned firstIndex, unsigned lastIndex );

			void onCurrentChanged( QListViewItem* currentItem );

			void onReplaceText( const QString& text, int replacementIndex, int replacedLength, int matchedLength );
			void onHighlightText( const QString& text, int matchingIndex, int matchedLength );

			void onSpellCheckReady();
			void onWordMisspelled( const QString& text, const QStringList&, unsigned int pos );
			void onWordCorrected( const QString& oldWord, const QString& newWord, unsigned int pos );
			void onSpellCheckDone( const QString& text );
			void onSpellCheckCleanup();

			void iterateFindError( bool backwards );

			void editLineTextInline();

		private:

			const AppConfigGroup& m_generalConfig;
			const AppConfigGroup& m_errorsConfig;

			Subtitle* m_subtitle;

			LinesViewItem* m_playingItem;

			KFind* m_find;
			KReplace* m_replace;
			bool m_findFound;
			KFindDialog* m_findDialog;
			KReplaceDialog* m_replaceDialog;
			LinesViewItem* m_findReplaceItem;

			KSpell* m_spell;
			LinesViewItem* m_spellItem;
			LinesViewItem* m_spellFirstItem;

			ConfigDialog* m_configDialog;
			LinesErrorsDialog* m_errorsDialog;

			bool m_nextItemCurrentOnDelete;
			bool m_contextMenuMode;
	};

}

#endif
