#ifndef MAINWINDOW_H
#define MAINWINDOW_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include "actions.h"
#include "playerwidget.h"
#include "linesview.h"
#include "currentlinewidget.h"
#include <appconfig.h>
#include <configdialog.h>
#include <subtitle.h>
#include <actionsmanager.h>

#include <kmainwindow.h>
#include <ktextedit.h>
#include <kaction.h>

#include <qptrlist.h>
#include <qmap.h>

namespace SubtitleComposer
{
	class MainWindow : public KMainWindow
	{
		Q_OBJECT

		public:
			MainWindow();
			virtual ~MainWindow();

		public slots:

			void openSubtitle( const KURL& url );

		signals:

			void subtitleOpened( Subtitle* subtitle );
			void subtitleClosed();

		protected:

			QMap<QString,QString> generalConfigDefaults();
			QMap<QString,QString> subTextConfigDefaults();
			QMap<QString,QString> errorsConfigDefaults();

			void saveConfig();
			void loadConfig();

			virtual bool queryClose();

			void setupActions();

			void addToRecentFiles( KURL url, const QString& encoding );
			void addToRecentFiles( const QString& path, const QString encoding );

			virtual bool eventFilter( QObject* object, QEvent* event );

		protected slots:

			void updateActionsState();
			void updateTitle();

			void newSubtitle();
			void openSubtitle();
			void openSubtitle( const QString& encoding );
			bool saveSubtitle();
			bool saveSubtitleAs();
			bool closeSubtitle();

			void joinSubtitles();
			void splitSubtitle();

			void onLineDoubleClicked( SubtitleLine* line );

			void showPreferences();
			void showConfirmQuit();
			void updateConfigFromDialog();

		protected:

			AppConfig m_config;

			ConfigDialog* m_configDialog;
			PlayerWidget* m_playerWidget;
			LinesView* m_linesView;
			CurrentLineWidget* m_curLineWidget;

			QString m_lastDir;

			ActionsManagerProxy m_actionsManagerProxy;

			Subtitle* m_subtitle;
			QString m_subtitlePath;
			QString m_subtitleEncoding;
			QString m_subtitleFormat;

			KAction* m_newSubtitleAction;
			KAction* m_openSubtitleAction;

			KRecentFilesActionExt* m_recentSubtitlesAction;

			KComboBox* m_encodingsComboBox;
			KWidgetAction* m_changeEncodingAction;
			KAction* m_saveSubtitleAction;
			KAction* m_saveSubtitleAsAction;
			KAction* m_closeSubtitleAction;

			KAction* m_undoAction;
			KAction* m_redoAction;
	};
}

#endif
