#ifndef VIDEOPLAYERWIDGET_H
#define VIDEOPLAYERWIDGET_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <player.h>

#include <sctime.h>
#include <subtitle.h>
#include <subtitleline.h>
#include <timeedit.h>
#include <appconfig.h>

#include <textoverlaywidget.h>
#include <quietslider.h>
#include <pointingslider.h>

#include <qwidget.h>
#include <qtoolbutton.h>
#include <qgroupbox.h>
#include <qlabel.h>

#include <kactioncollection.h>

class LayeredWidget;

namespace SubtitleComposer
{
	class KActionExt;
	class KToggleActionExt;
	class KRecentFilesActionExt;
	class SubtitleActionWrapper;

	class PlayerWidget : public QWidget
	{
		Q_OBJECT

		public:

			PlayerWidget( const AppConfig& config, QWidget* parent );
			virtual ~PlayerWidget();

			void saveConfig();
			void loadConfig();

		public slots:

			void loadSubtitle( Subtitle* subtitle );
			void closeSubtitle();

			void openVideo();
			bool openVideo( const KURL& url );
			void openVideoForSubtitle( const QString& subtitlePath );
			void closeVideo();

		signals:

			void setPlayingLine( SubtitleLine* line );
			void setCurrentLine( SubtitleLine* line );

			void setCurrentLineShowTime( const Time& showTime );
			void setCurrentLineHideTime( const Time& hideTime );

			void adjustFromCurrentLine( const Time& currentLineShowTime );
			void adjustUpToCurrentLine( const Time& currentLineShowTime );

			void shiftFromCurrentLine( const Time& currentLineShowTime );
			void shiftUpToCurrentLine( const Time& currentLineShowTime );

		protected:

			virtual void mouseReleaseEvent( QMouseEvent* event );
			virtual bool eventFilter( QObject* object, QEvent* event );

			void setupActions();

			void updateOverlayLine( const Time& time );
			void connectOverlayLine();
			void disconnectOverlayLine();

			void updatePlayingLine( SubtitleLine* playingLine );

		protected slots:

			void invalidateOverlayLine();

			void connectActivePlayer();
			void disconnectActivePlayer();

			void seekBackwards();
			void seekForwards();

			void jumpToPreviousLine();
			void jumpToNextLine();

			void setCurrentLineShowTime();
			void setCurrentLineHideTime();

			void adjustFromCurrentLine();
			void adjustUpToCurrentLine();

			void shiftFromCurrentLine();
			void shiftUpToCurrentLine();

			void onSeekSliderValueChanged( int position );
			void onSeekSliderDragged( int position );
			void onSeekSliderPressed();
			void onSeekSliderReleased();

			void onPositionEditValueChanged( int position );

			void onVolumeSliderValueChanged( int position );
			void onMuteButtonToggled( bool value );
			void onLinkCurrentToPositionToggled( bool value );

			void onGeneralOptionChanged( const QString& option, const QString& value );
			void onSubsFontOptionChanged();

			void showAudioTracksMenu( const QPoint& point );

			void updateControlsState();
			void setControlsStateOpened();
			void setControlsStateClosed();
			void setControlsStatePlaying();
			void setControlsStatePaused();
			void setControlsStateStopped();
			void updatePositionControls( double seconds );
			void updateLengthControls( double seconds );
			void updateFramesPerSecondControls( double framesPerSecond );

		protected:

			const AppConfigGroup& m_generalConfig;
			const AppConfigGroup& m_fontConfigGroup;

			Subtitle* m_subtitle;
			SubtitleLine* m_overlayLine;
			SubtitleLine* m_playingLine;
			Time m_lastSearchedLineToShowTime;
			Time m_lastTime;

			Player* m_activePlayer;
			QString m_subtitlePath;
			QString m_lastDir;

			LayeredWidget* m_layeredWidget;
			TextOverlayWidget* m_textOverlay;
			QuietSlider* m_seekSlider;
			PointingSlider* m_volumeSlider;
			int m_updatePositionControls; // "true" when >0
			bool m_updateVideoPosition;
			int m_updatePositionLabel;

			QGroupBox* m_infoControlsGroupBox;
			QLabel* m_positionTagLabel;
			QLabel* m_positionLabel;
			TimeEdit* m_positionEdit;
			bool m_showPositionEdit;
			QLabel* m_lengthTagLabel;
			QLabel* m_lengthLabel;
			QLabel* m_fpsTagLabel;
			QLabel* m_fpsLabel;

			KAction* m_closeVideoAction;
			KRecentFilesActionExt* m_recentVideosAction;

			QToolButton* m_stopButton;
			KActionExt* m_stopAction;
			QIconSet m_playIconSet;
			QIconSet m_pauseIconSet;
			QToolButton* m_playPauseButton;
			KActionExt* m_playPauseAction;

			QToolButton* m_seekBackwardsButton;
			KActionExt* m_seekBackwardsAction;
			QToolButton* m_seekForwardsButton;
			KActionExt* m_seekForwardsAction;

			QToolButton* m_toggleMuteButton;
			KToggleActionExt* m_toggleMuteAction;

			KListAction* m_selectAudioTrackAction;


			QToolButton* m_previousLineButton;
			SubtitleActionWrapper* m_previousLineAction;
			QToolButton* m_nextLineButton;
			SubtitleActionWrapper* m_nextLineAction;

			QToolButton* m_setLineShowTimeButton;
			SubtitleActionWrapper* m_setLineShowTimeAction;
			QToolButton* m_setLineHideTimeButton;
			SubtitleActionWrapper* m_setLineHideTimeAction;

			QToolButton* m_linkCurrentLineToVideoButton;
			KToggleActionExt* m_linkCurrentLineToVideoAction;

			SubtitleActionWrapper* m_adjustFromCurrentLineAction;
			SubtitleActionWrapper* m_adjustUpToCurrentLineAction;
			SubtitleActionWrapper* m_shiftFromCurrentLineAction;
			SubtitleActionWrapper* m_shiftUpToCurrentLineAction;
	};

}

#endif
