/***************************************************************************
 *   smplayer, GUI front-end for mplayer.                                  *
 *   Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>           *
 *                                                                         *
 *   modified for inclusion in Subtitle Composer                           *
 *   Copyright (C) 2007 by Sergio Pistone <sergio_pistone@yahoo.com.ar>    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "mediadata.h"

using namespace SubtitleComposer;

TrackDataList::TrackDataList()
{
}

TrackDataList::~TrackDataList()
{
}

void TrackDataList::clear()
{
	m_tracksMap.clear();
}

void TrackDataList::addLang( int ID, QString lang )
{
	m_tracksMap[ID].setLang( lang );
	m_tracksMap[ID].setID( ID );
}

void TrackDataList::addName( int ID, QString name )
{
	m_tracksMap[ID].setName( name );
	m_tracksMap[ID].setID( ID );
}

void TrackDataList::addDuration( int ID, double duration )
{
	m_tracksMap[ID].setDuration( duration );
	m_tracksMap[ID].setID( ID );
}

void TrackDataList::addID( int ID )
{
	m_tracksMap[ID].setID(ID);
}

int TrackDataList::tracksCount() const
{
	return m_tracksMap.count();
}

const TrackData& TrackDataList::itemAt( int index ) const
{
	return m_tracksMap.values()[index];
}

const TrackData& TrackDataList::item( int ID ) const
{
	return m_tracksMap[ID];
}

MediaData::MediaData()
{
	reset();
}

MediaData::~MediaData()
{
}

void MediaData::reset()
{
	duration = 0;

	hasVideo = true;

	videoWidth = 0;
    videoHeight = 0;
    videoAspect = 4.0/3.0;
	videoFPS = 0.0;

	audioTracks.clear();
	subtitleTracks.clear();
}
