#ifndef MEDIADATA_H
#define MEDIADATA_H

/***************************************************************************
 *   smplayer, GUI front-end for mplayer.                                  *
 *   Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>           *
 *                                                                         *
 *   modified for inclusion in Subtitle Composer                           *
 *   Copyright (C) 2007 by Sergio Pistone <sergio_pistone@yahoo.com.ar>    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <qstring.h>
#include <qmap.h>

namespace SubtitleComposer
{
	class TrackData
	{
		public:

			TrackData(): m_lang(), m_name(), m_duration( 0 ), m_ID( -1 ) {};
			~TrackData() {};

			void setLang( const QString& lang ) { m_lang = lang; };
			void setName( const QString& name ) { m_name = name; };
			void setDuration( double duration ) { m_duration = duration; };
			void setID( int ID ) { m_ID = ID; };

			QString lang() const { return m_lang; };
			QString name() const { return m_name; };
			double duration() const { return m_duration; };
			int ID() const { return m_ID; };

		protected:

			QString m_lang; /* Language code: es, en, etc. */
			QString m_name; /* spanish, english... */
			double m_duration; /* For dvd titles */
			int m_ID;
	};

	class TrackDataList
	{
		public:

			TrackDataList();
			~TrackDataList();

			void clear();

			void addLang( int ID, QString lang );
			void addName( int ID, QString name );
			void addDuration( int ID, double duration );
			void addID( int ID );

			int tracksCount() const;
			const TrackData& itemAt( int index ) const;
			const TrackData& item( int ID ) const;

		protected:

			QMap<int,TrackData> m_tracksMap;
	};

	class MediaData
	{
		public:

			MediaData();
			virtual ~MediaData();

			virtual void reset();

			double duration;

			int videoWidth;
			int videoHeight;
			double videoAspect;
			double videoFPS;

			bool hasVideo;

			TrackDataList audioTracks;
			TrackDataList subtitleTracks;
	};
}

#endif
