#ifndef MPLAYERPROCESS_H
#define MPLAYERPROCESS_H

/***************************************************************************
 *   smplayer, GUI front-end for mplayer.                                  *
 *   Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>           *
 *                                                                         *
 *   modified for inclusion in Subtitle Composer                           *
 *   Copyright (C) 2007 by Sergio Pistone <sergio_pistone@yahoo.com.ar>    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <appconfiggroup.h>
#include "mediadata.h"

#include <qprocess.h>
#include <qstring.h>

class QStringList;

namespace SubtitleComposer
{
	class MPlayerProcess : public QProcess
	{
		Q_OBJECT

		public:
			MPlayerProcess( const AppConfigGroup& configGroup, QObject* parent=0, const char* name=0 );
			~MPlayerProcess();

			const MediaData& mediaData();

			virtual bool start( QStringList* env=0 );
			void waitForProcess();

			void sendMute( bool pause=false );
			void sendPause();
			void sendFrameStep();
			void sendSeek( double seconds, bool pause=false );

			void sendVolume( double volume );
			void sendAudioStream( int audioStream );

			void sendQuit();

		signals:

			void mediaDataLoaded();
			void receivedCurrentPosition( double seconds );
			void receivedPauseToggled();
			void receivedWindowResolution( int width, int height );
			void receivedEndOfFile();

		private slots:

			void read();
			void read( const QByteArray& newText );
			void readFromStderr();

		private:

			void parseLine( const QString& line );
			void initRegularExpressions();

		private:

			const AppConfigGroup& m_configGroup;
			MediaData m_mediaData;

			QString m_incompleteLine;
			bool m_hasNotifiedRunning;
			bool m_isPaused;
	};
}

#endif
