/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "videowidget.h"

#include <qapplication.h>
#include <qdesktopwidget.h>

using namespace SubtitleComposer;

PlayerVideoWidgetBase::PlayerVideoWidgetBase( QWidget* parent, const char* name, WFlags f ):
	QWidget( parent, name, f )
{
	setBackgroundColor( Qt::black );
	setFocusPolicy( QWidget::NoFocus );
}

PlayerVideoWidgetBase::~PlayerVideoWidgetBase()
{
}

void PlayerVideoWidgetBase::mouseReleaseEvent( QMouseEvent* e )
{
	if ( e->button() == Qt::LeftButton )
	{
		e->accept();
		emit leftClicked( e->globalPos() );
	}
	else if ( e->button() == Qt::RightButton )
	{
		e->accept();
		emit rightClicked( e->globalPos() );
	}
	else
		e->ignore();
}

void PlayerVideoWidgetBase::mouseDoubleClickEvent( QMouseEvent* e )
{
	e->accept();
	emit doubleClicked( e->globalPos() );
}

void PlayerVideoWidgetBase::wheelEvent( QWheelEvent * e )
{
	e->accept();
	if ( e->delta() >= 0 )
		emit wheelUp();
	else
		emit wheelDown();
}


PlayerVideoWidget::PlayerVideoWidget( QWidget* parent, const char* name, WFlags fl ):
	PlayerVideoWidgetBase( parent, name, fl|Qt::WStaticContents|Qt::WNoAutoErase ),
	m_videoLayer( new PlayerVideoWidgetBase( this, "VideoLayer", Qt::WStaticContents|Qt::WNoAutoErase ) ),
	m_videoWidth( 0 ),
	m_videoHeight( 0 ),
	m_videoAspect( 4.0 / 3.0 )
{
	connect( m_videoLayer, SIGNAL( doubleClicked(const QPoint&) ), this, SIGNAL( doubleClicked(const QPoint&) ) );
	connect( m_videoLayer, SIGNAL( rightClicked(const QPoint&) ), this, SIGNAL( rightClicked(const QPoint&) ) );
	connect( m_videoLayer, SIGNAL( leftClicked(const QPoint&) ), this, SIGNAL( leftClicked(const QPoint&) ) );
	connect( m_videoLayer, SIGNAL( wheelUp() ), this, SIGNAL( wheelUp() ) );
	connect( m_videoLayer, SIGNAL( wheelDown() ), this, SIGNAL( wheelDown() ) );
}

PlayerVideoWidget::~PlayerVideoWidget()
{
}

PlayerVideoWidgetBase* PlayerVideoWidget::videoLayer()
{
	return m_videoLayer;
}

void PlayerVideoWidget::setVideoResolution( int width, int height )
{
	m_videoWidth = width;
	m_videoHeight = height;
	m_videoAspect = (double)width/height;

	updateVideoLayerGeometry();
}


void PlayerVideoWidget::resizeEvent( QResizeEvent* )
{
	updateVideoLayerGeometry();
}

void PlayerVideoWidget::paintEvent( QPaintEvent* )
{
}

QSize PlayerVideoWidget::desktopSize()
{
	QRect rect = QApplication::desktop()->screenGeometry( this );
	return QSize( rect.width(), rect.height() );
}

double PlayerVideoWidget::desktopAspectRatio()
{
	QSize size = desktopSize();
	return (double)size.width() / size.height() ;
}

void PlayerVideoWidget::updateVideoLayerGeometry()
{
	QSize frameSize = size();

	int videoLayerX = 0;
	int videoLayerY = 0;
	int videoLayerWidth = frameSize.width();
	int videoLayerHeight = frameSize.height();

	if ( m_videoWidth != 0 && m_videoHeight != 0 )
	{
		if ( m_videoAspect >= ((double)videoLayerWidth / videoLayerHeight) )
		{
			videoLayerHeight = (int)(videoLayerWidth / m_videoAspect);
			videoLayerY = (frameSize.height() - videoLayerHeight) / 2;
		}
		else
		{
			videoLayerWidth = (int)(videoLayerHeight * m_videoAspect);
			videoLayerX = (frameSize.width() - videoLayerWidth) / 2;
		}
	}

	m_videoLayer->setGeometry( videoLayerX, videoLayerY, videoLayerWidth, videoLayerHeight );
}

QSize PlayerVideoWidget::sizeHint() const
{
	return QSize( m_videoWidth, m_videoHeight );
}

QSize PlayerVideoWidget::minimumSizeHint() const
{
	return QSize( 0, 0 );
}
