/***************************************************************************
 *   smplayer, GUI front-end for mplayer.                                  *
 *   Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>           *
 *                                                                         *
 *   modified for inclusion in Subtitle Composer                           *
 *   Copyright (C) 2007 by Sergio Pistone <sergio_pistone@yahoo.com.ar>    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "quietslider.h"
#include "pointingslider.h"

#include <qlayout.h>

QuietSlider::QuietSlider( QWidget* parent, const char* name ):
	QWidget( parent, name ),
	m_slider( new PointingSlider( this, name ) ),
	m_value( m_slider->value() ),
	m_update( true )
{
	setOrientation( orientation() );

#if QT_VERSION < 0x040000
	setFocusPolicy( QWidget::NoFocus );
	m_slider->setFocusPolicy( QWidget::NoFocus );
#else
	setFocusPolicy( Qt::NoFocus );
	m_slider->setFocusPolicy( Qt::NoFocus );
#endif

	setSizePolicy( QSizePolicy::Expanding , QSizePolicy::Fixed );
	m_slider->setSizePolicy( QSizePolicy::Expanding , QSizePolicy::Fixed );

	connect( m_slider, SIGNAL( sliderPressed() ), this, SLOT( onSliderPressed() ) );
	connect( m_slider, SIGNAL( sliderReleased() ), this, SLOT( onSliderReleased() ) );
	connect( m_slider, SIGNAL( valueChanged(int) ), this, SLOT( onSliderValueChanged(int) ) );
}


QuietSlider::QuietSlider( Orientation orient, QWidget* parent, const char* name ):
	QWidget( parent, name ),
	m_slider( new PointingSlider( orient, this, name ) ),
	m_value( m_slider->value() ),
	m_update( true )
{
	setOrientation( orientation() );

#if QT_VERSION < 0x040000
	setFocusPolicy( QWidget::NoFocus );
	m_slider->setFocusPolicy( QWidget::NoFocus );
#else
	setFocusPolicy( Qt::NoFocus );
	m_slider->setFocusPolicy( Qt::NoFocus );
#endif

	setSizePolicy( QSizePolicy::Expanding , QSizePolicy::Fixed );
	m_slider->setSizePolicy( QSizePolicy::Expanding , QSizePolicy::Fixed );

	connect( m_slider, SIGNAL( sliderPressed() ), this, SLOT( onSliderPressed() ) );
	connect( m_slider, SIGNAL( sliderReleased() ), this, SLOT( onSliderReleased() ) );
	connect( m_slider, SIGNAL( valueChanged(int) ), this, SLOT( onSliderValueChanged(int) ) );
}




QuietSlider::QuietSlider( int minValue, int maxValue, int pageStep, int value, Orientation orient, QWidget* parent, const char* name ):
	QWidget( parent, name ),
	m_slider( new PointingSlider( minValue, maxValue, pageStep, value, orient, this, name ) ),
	m_value( m_slider->value() ),
	m_update( true )
{
	setOrientation( orientation() );

#if QT_VERSION < 0x040000
	setFocusPolicy( QWidget::NoFocus );
	m_slider->setFocusPolicy( QWidget::NoFocus );
#else
	setFocusPolicy( Qt::NoFocus );
	m_slider->setFocusPolicy( Qt::NoFocus );
#endif

	setSizePolicy( QSizePolicy::Expanding , QSizePolicy::Fixed );
	m_slider->setSizePolicy( QSizePolicy::Expanding , QSizePolicy::Fixed );

	connect( m_slider, SIGNAL( sliderPressed() ), this, SLOT( onSliderPressed() ) );
	connect( m_slider, SIGNAL( sliderReleased() ), this, SLOT( onSliderReleased() ) );
	connect( m_slider, SIGNAL( valueChanged(int) ), this, SLOT( onSliderValueChanged(int) ) );
}

QuietSlider::~QuietSlider()
{
}

void QuietSlider::onSliderPressed()
{
	m_update = false;
	emit sliderPressed();
}

void QuietSlider::onSliderReleased()
{
	m_update = true;
	emit sliderReleased();
	emit valueChanged( m_slider->value() );
}

void QuietSlider::onSliderValueChanged( int value )
{
	// Only to make things clear:
	if ( ! m_update )
		emit sliderMoved( value );
	else
	{
		if ( value != m_value )
			emit valueChanged( value );
	}
}

int QuietSlider::value() const
{
	return m_value;
}

void QuietSlider::setValue( int value )
{
	if ( value != m_value )
	{
		if ( m_update )
		{
			m_value = value;
			m_slider->setValue( value );
		}
	}
}


Qt::Orientation QuietSlider::orientation() const
{
	return m_slider->orientation();
}

void QuietSlider::setOrientation( Orientation orientation )
{
	m_slider->setOrientation( orientation );
	QLayout* layout;
	if ( this->orientation() == Qt::Horizontal )
		layout = new QHBoxLayout( this, 0, 0 );
	else
		layout = new QVBoxLayout( this, 0, 0 );
	layout->setMargin( 0 );
	layout->setSpacing( 0 );
	layout->add( m_slider );
}

bool QuietSlider::tracking() const
{
	return m_slider->tracking();
}

void QuietSlider::setTracking( bool enable )
{
	m_slider->setTracking( enable );
}

int QuietSlider::sliderStart() const
{
	return m_slider->sliderStart();
}

QRect QuietSlider::sliderRect() const
{
	return m_slider->sliderRect();
}

void QuietSlider::setPalette( const QPalette& p )
{
	m_slider->setPalette( p );
}

QSlider::TickSetting QuietSlider::tickmarks() const
{
	return m_slider->tickmarks();
}

void QuietSlider::setTickmarks( QSlider::TickSetting settings )
{
	m_slider->setTickmarks( settings );
}


int QuietSlider::tickInterval() const
{
	return m_slider->tickInterval();
}

void QuietSlider::setTickInterval( int tickInterval )
{
	m_slider->setTickInterval( tickInterval );
}

int QuietSlider::minValue() const
{
	return m_slider->minValue();
}

int QuietSlider::maxValue() const
{
	return m_slider->maxValue();
}

void QuietSlider::setMinValue( int minValue )
{
	m_slider->setMinValue( minValue );
}

void QuietSlider::setMaxValue( int maxValue )
{
	m_slider->setMaxValue( maxValue );
}

int QuietSlider::lineStep() const
{
	return m_slider->lineStep();
}

void QuietSlider::setLineStep( int lineStep )
{
	m_slider->setLineStep( lineStep );
}

int QuietSlider::pageStep() const
{
	return m_slider->pageStep();
}

void QuietSlider::setPageStep( int pageStep )
{
	m_slider->setPageStep( pageStep );
}

void QuietSlider::addStep()
{
	m_slider->addStep();
}

void QuietSlider::subtractStep()
{
	m_slider->subtractStep();
}
