#ifndef SILENTSLIDER_H
#define SILENTSLIDER_H

/***************************************************************************
 *   smplayer, GUI front-end for mplayer.                                  *
 *   Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>           *
 *                                                                         *
 *   modified for inclusion in Subtitle Composer                           *
 *   Copyright (C) 2007 by Sergio Pistone <sergio_pistone@yahoo.com.ar>    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <qwidget.h>
#include <qslider.h>
#include <qwidgetplugin.h>

class PointingSlider;

class QT_WIDGET_PLUGIN_EXPORT QuietSlider : public QWidget
{
	Q_OBJECT

	public:

		QuietSlider( QWidget* parent=0, const char* name=0 );
		QuietSlider( Orientation orientation, QWidget* parent=0, const char* name=0 );
		QuietSlider( int minValue, int maxValue, int pageStep, int value, Orientation orientation, QWidget* parent=0, const char* name=0 );
		~QuietSlider();

	public slots:

		int value() const;

		Orientation orientation() const;
		virtual void setOrientation( Orientation );

		bool tracking() const;
		virtual void setTracking( bool enable );

		int sliderStart() const;
		QRect sliderRect() const;

		virtual void setPalette( const QPalette& p );

		QSlider::TickSetting tickmarks() const;
		virtual void setTickmarks( QSlider::TickSetting );

		int tickInterval() const;
		virtual void setTickInterval( int tickInterval );

		int minValue() const;
		int maxValue() const;
		void setMinValue( int minValue );
		void setMaxValue( int maxValue );

		int lineStep() const;
		void setLineStep( int lineStep );

		int pageStep() const;
		void setPageStep( int pageStep );

	public slots:

		virtual void setValue( int value );
		void addStep();
		void subtractStep();

	signals:

		void valueChanged( int value );
		void sliderMoved( int value );
		void sliderPressed();
		void sliderReleased();

	protected slots:

		void onSliderPressed();
		void onSliderReleased();
		void onSliderValueChanged(int);

	protected:
		PointingSlider* m_slider;
		int m_value;
		bool m_update;
};

#endif
