/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "widgetsplugin.h"
#include "images.h"

#include <layeredwidget.h>
#include <pointingslider.h>
#include <quietslider.h>
#include <textedit.h>
#include <textoverlaywidget.h>
#include <timeedit.h>

WidgetsPlugin::WidgetsPlugin()
{
}

QStringList WidgetsPlugin::keys() const
{
	QStringList list;
	list 	<< "SC_LayeredWidget"
			<< "SC_PointingSlider"
			<< "SC_QuietSlider"
			<< "SC_TextEdit"
			<< "SC_TextOverlayWidget"
			<< "SC_TimeEdit";
	return list;
}

QWidget* WidgetsPlugin::create( const QString& key, QWidget* parent, const char* name )
{
	if ( key == "SC_LayeredWidget" )
		return new LayeredWidget( parent, name );
	else if ( key == "SC_PointingSlider" )
		return new PointingSlider( parent, name );
	else if ( key == "SC_QuietSlider" )
		return new QuietSlider( parent, name );
	else if ( key == "SC_TextEdit" )
		return new TextEdit( parent, name );
	else if ( key == "SC_TextOverlayWidget" )
		return new TextOverlayWidget( parent, name );
	else if ( key == "SC_TimeEdit" )
		return new TimeEdit( parent, name );
	else
		return 0;
}

QString WidgetsPlugin::includeFile( const QString& feature ) const
{
	if ( feature == "SC_LayeredWidget" )
		return "layeredwidget.h";
	else if ( feature == "SC_PointingSlider" )
		return "pointingslider.h";
	else if ( feature == "SC_QuietSlider" )
		return "quietslider.h";
	else if ( feature == "SC_TextEdit" )
		return "textedit.h";
	else if ( feature == "SC_TextOverlayWidget" )
		return "textoverlaywidget.h";
	else if ( feature == "SC_TimeEdit" )
		return "timeedit.h";
	else
		return QString::null;
}

QString WidgetsPlugin::group( const QString& feature ) const
{
	if ( feature == "SC_LayeredWidget" )
		return "Containers";
	else if ( feature == "SC_PointingSlider" )
		return "Input";
	else if ( feature == "SC_QuietSlider" )
		return "Input";
	else if ( feature == "SC_TextEdit" )
		return "Input";
	else if ( feature == "SC_TextOverlayWidget" )
		return "Display";
	else if ( feature == "SC_TimeEdit" )
		return "Input";
	else
		return QString::null;
}

QIconSet WidgetsPlugin::iconSet( const QString& key ) const
{
	if ( key == "SC_LayeredWidget" )
		return QIconSet( QPixmap( qembed_findImage( "LayeredWidget" ) ) );
	else if ( key == "SC_PointingSlider" )
		return QIconSet( QPixmap( qembed_findImage( "PointingSlider" ) ) );
	else if ( key == "SC_QuietSlider" )
		return QIconSet( QPixmap( qembed_findImage( "QuietSlider" ) ) );
	else if ( key == "SC_TextEdit" )
		return QIconSet( QPixmap( qembed_findImage( "TextEdit" ) ) );
	else if ( key == "SC_TextOverlayWidget" )
		return QIconSet( QPixmap( qembed_findImage( "TextOverlayWidget" ) ) );
	else if ( key == "SC_TimeEdit" )
		return QIconSet( QPixmap( qembed_findImage( "TimeEdit" ) ) );
	else
		return QIconSet();
}

QString WidgetsPlugin::toolTip( const QString& feature ) const
{
	return feature.mid( 2 );
}

QString WidgetsPlugin::whatsThis( const QString& feature ) const
{
	if ( feature == "SC_LayeredWidget" )
		return "<qt>A widget that paints all of its children in the same region, one on top of the other. See also TextOverlayWidget</qt>";
	else if ( feature == "SC_PointingSlider" )
		return "<qt>A silder that instead of stepping towards it, sets the value to the clicked position.</qt>";
	else if ( feature == "SC_QuietSlider" )
		return "<qt>A silder whose valueChanged signals are only sent when the handle is released. Inherits PointingSlider.</qt>";
	else if ( feature == "SC_TextEdit" )
		return "<qt>A text edit that follows KDE conventions and <b>doesn't resets the style flags when setting its text...</b></qt>";
	else if ( feature == "SC_TextOverlayWidget" )
		return "<qt>A widget to overlay text on top of other widgets. See also LayeredWidget.</qt>";
	else if ( feature == "SC_TimeEdit" )
		return "<qt>A widget to enter time as hh:mm:ss,zzz.</qt>";
	else
		return QString::null;
}

bool WidgetsPlugin::isContainer( const QString& key ) const
{
	return key == "SC_LayeredWidget";
}

Q_EXPORT_PLUGIN( WidgetsPlugin )
